@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/group.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -17,7 +17,6 @@
 #include <ioncore/rectangle.h>
 #include <ioncore/pholder.h>
 #include <ioncore/stacking.h>
-#include <ioncore/framedpholder.h>
 
 
 INTRSTRUCT(WGroupAttachParams);
@@ -54,6 +53,7 @@ DECLCLASS(WGroup){
     WStacking *current_managed;
     WStacking *bottom;
     Window dummywin;
+    WGroupPHolder *phs;
 };
 
 
@@ -72,6 +72,9 @@ DYNFUN WStacking *group_do_add_managed(WGroup *ws, WRegion *reg,
 extern WStacking *group_do_add_managed_default(WGroup *ws, WRegion *reg, 
                                                int level, WSizePolicy szplcy);
 
+extern void group_get_attach_params(WGroup *ws, ExtlTab tab, 
+                                    WGroupAttachParams *par);
+
 extern WRegion *group_do_attach(WGroup *ws, 
                                 WGroupAttachParams *param,
                                 WRegionAttachData *data);
@@ -91,6 +94,7 @@ extern void group_managed_notify(WGroup *ws, WRegion *reg, WRegionNotify how);
 
 extern WRegion *group_bottom(WGroup *ws);
 extern bool group_set_bottom(WGroup *ws, WRegion *reg);
+DYNFUN void group_bottom_set(WGroup *grp);
 
 extern bool group_rescue_clientwins(WGroup *ws, WRescueInfo *info);
 
