@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/mplex.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  * 
  * See the included file LICENSE for details.
  */
@@ -30,12 +30,13 @@
 #define MPLEX_ATTACH_SWITCHTO     0x0001 /* switch to region */
 #define MPLEX_ATTACH_UNNUMBERED   0x0002 /* do not put on mut.ex list */
 #define MPLEX_ATTACH_HIDDEN       0x0004 /* should be hidden */
-#define MPLEX_ATTACH_PSEUDOMODAL  0x0004 /* pseudomodal (if modal) */
+#define MPLEX_ATTACH_PSEUDOMODAL  0x0008 /* pseudomodal (if modal) */
 #define MPLEX_ATTACH_LEVEL        0x0010 /* level field set */
 #define MPLEX_ATTACH_GEOM         0x0020 /* geometry field is set */
 #define MPLEX_ATTACH_SIZEPOLICY   0x0040 /* size policy field is set */
 #define MPLEX_ATTACH_INDEX        0x0080 /* index field is set */
 #define MPLEX_ATTACH_WHATEVER     0x0100 /* set REGION_FIT_WHATEVER */
+#define MPLEX_ATTACH_PASSIVE      0x0200 /* sets SKIP_FOCUS */
 
 
 enum{
@@ -93,7 +94,7 @@ DECLCLASS(WMPlex){
     int mx_count;
     WLListNode *mx_current;
     WLListNode *mx_list;
-    WMPlexPHolder *mx_phs;
+    WMPlexPHolder *misc_phs;
     
     Watch stdispwatch;
     WMPlexSTDispInfo stdispinfo;
@@ -184,6 +185,12 @@ extern void mplex_call_changed_hook(WMPlex *mplex, WHook *hook,
 
 extern void mplex_remanage_stdisp(WMPlex *mplex);
 
+/* Note: only the size policy field is changed; actual geometry is not
+ * yet changed.
+ */
+extern void mplex_set_szplcy(WMPlex *mplex, WRegion *sub, WSizePolicy szplcy);
+extern WSizePolicy mplex_get_szplcy(WMPlex *mplex, WRegion *sub);
+
 /* Dynfuns */
 
 DYNFUN void mplex_managed_geom(const WMPlex *mplex, WRectangle *geom);
