@@ -1,7 +1,7 @@
 /*
  * ion/mod_query/input.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -25,7 +25,7 @@ DECLCLASS(WInput){
 extern bool input_init(WInput *input, WWindow *par, const WFitParams *fp);
 extern void input_deinit(WInput *input);
 
-extern void input_fitrep(WInput *input, WWindow *par, const WFitParams *fp);
+extern bool input_fitrep(WInput *input, WWindow *par, const WFitParams *fp);
 extern void input_refit(WInput *input);
 extern void input_cancel(WInput *input);
 extern bool input_rqclose(WInput *input);
